==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/StepAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { StepAreaSeriesDescription } from "./StepAreaSeriesDescription";
/**
 * @hidden
 */
var StepAreaSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StepAreaSeriesDescriptionMetadata, _super);
    function StepAreaSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StepAreaSeriesDescriptionMetadata.b = function (a) {
        if (StepAreaSeriesDescriptionMetadata.a == null) {
            StepAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StepAreaSeriesDescriptionMetadata.c(StepAreaSeriesDescriptionMetadata.a);
        }
        if (a.g(StepAreaSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(StepAreaSeriesDescriptionMetadata.a);
    };
    StepAreaSeriesDescriptionMetadata.c = function (a) {
        HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
    };
    StepAreaSeriesDescriptionMetadata.d = function (a) {
        StepAreaSeriesDescriptionMetadata.b(a);
        a.u("StepAreaSeries", function () { return new StepAreaSeriesDescription(); });
        a.t("StepAreaSeries", StepAreaSeriesDescriptionMetadata.a);
    };
    StepAreaSeriesDescriptionMetadata.$t = markType(StepAreaSeriesDescriptionMetadata, 'StepAreaSeriesDescriptionMetadata');
    StepAreaSeriesDescriptionMetadata.a = null;
    return StepAreaSeriesDescriptionMetadata;
}(Base));
export { StepAreaSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/StepAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { StepAreaSeriesDescription } from "./StepAreaSeriesDescription";
/**
 * @hidden
 */
var StepAreaSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StepAreaSeriesDescriptionMetadata, _super);
    function StepAreaSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StepAreaSeriesDescriptionMetadata.b = function (a) {
        if (StepAreaSeriesDescriptionMetadata.a == null) {
            StepAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StepAreaSeriesDescriptionMetadata.c(StepAreaSeriesDescriptionMetadata.a);
        }
        if (a.j(StepAreaSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(StepAreaSeriesDescriptionMetadata.a);
    };
    StepAreaSeriesDescriptionMetadata.c = function (a) {
        HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
    };
    StepAreaSeriesDescriptionMetadata.d = function (a) {
        StepAreaSeriesDescriptionMetadata.b(a);
        a.aa("StepAreaSeries", function () { return new StepAreaSeriesDescription(); });
        a.z("StepAreaSeries", StepAreaSeriesDescriptionMetadata.a);
    };
    StepAreaSeriesDescriptionMetadata.$t = markType(StepAreaSeriesDescriptionMetadata, 'StepAreaSeriesDescriptionMetadata');
    StepAreaSeriesDescriptionMetadata.a = null;
    return StepAreaSeriesDescriptionMetadata;
}(Base));
export { StepAreaSeriesDescriptionMetadata };
